fnss.netconfig.nodeconfig.get_application_names — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »

# fnss.netconfig.nodeconfig.get_application_names

`get_application_names`(topology, node)

  Return a list of names of applications deployed on a node

  Parameters : | topology : Topology The topology node : any hashable type The ID of the node
  Returns : | application_names : list A list of application names

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.5.0 documentation »
- API Reference »
- Functions »